==> apache-camel-4.8.9-src.zip: apache-camel-4.8.9/components/camel-aws/camel-aws2-mq/src/main/java/org/apache/camel/component/aws2/mq/client/MQ2ClientFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws2.mq.client;

import org.apache.camel.component.aws2.mq.MQ2Configuration;
import org.apache.camel.component.aws2.mq.client.impl.MQ2ClientOptimizedImpl;
import org.apache.camel.component.aws2.mq.client.impl.MQ2ClientProfileOptimizedImpl;
import org.apache.camel.component.aws2.mq.client.impl.MQ2ClientSessionTokenImpl;
import org.apache.camel.component.aws2.mq.client.impl.MQ2ClientStandardImpl;

/**
 * Factory class to return the correct type of AWS MQ client.
 */
public final class MQ2ClientFactory {

    private MQ2ClientFactory() {
    }

    /**
     * Return the correct AWS Mq client (based on remote vs local).
     *
     * @param  configuration configuration
     * @return               MqClient
     */
    public static MQ2InternalClient getMqClient(MQ2Configuration configuration) {
        if (Boolean.TRUE.equals(configuration.isUseDefaultCredentialsProvider())) {
            return new MQ2ClientOptimizedImpl(configuration);
        } else if (Boolean.TRUE.equals(configuration.isUseProfileCredentialsProvider())) {
            return new MQ2ClientProfileOptimizedImpl(configuration);
        } else if (Boolean.TRUE.equals(configuration.isUseSessionCredentials())) {
            return new MQ2ClientSessionTokenImpl(configuration);
        } else {
            return new MQ2ClientStandardImpl(configuration);
        }
    }
}

==> apache-camel-4.17.0-src.zip: apache-camel-4.17.0/components/camel-aws/camel-aws2-mq/src/main/java/org/apache/camel/component/aws2/mq/client/MQ2ClientFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws2.mq.client;

import org.apache.camel.component.aws.common.AwsClientBuilderUtil;
import org.apache.camel.component.aws2.mq.MQ2Configuration;
import software.amazon.awssdk.services.mq.MqClient;

/**
 * Factory class to create AWS MQ clients using common configuration.
 */
public final class MQ2ClientFactory {

    private MQ2ClientFactory() {
    }

    /**
     * Create an MQ client based on configuration.
     *
     * @param  configuration The MQ configuration
     * @return               Configured MqClient
     */
    public static MqClient getMqClient(MQ2Configuration configuration) {
        return AwsClientBuilderUtil.buildClient(
                configuration,
                MqClient::builder);
    }
}
